@@ -1,7 +1,9 @@
 import unittest
-
 from c1algo2 import forecaster
 from test import io
+import logging
+
+logging.basicConfig(level=logging.WARNING)
 
 
 class TestForecaster(unittest.TestCase):
